# gmalg

使用纯 Python 实现的国密算法库.

计算效率较低, 仅仅用于体验和学习国密算法.

## 安装

```bat
pip install gmalg
```

## 已实现的核心算法

- [x] 祖冲之序列密码算法
- [ ] SM2 椭圆曲线公钥密码算法
- [x] SM3 密码杂凑算法
- [x] SM4 分组密码算法
- [ ] SM9 标识密码算法

## 接口

TODO

---

*If you think this project is helpful to you, :star: it and let more people see!*
